import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
    
setuptools.setup(name='tiniyo',
      version='1.0.5',
      description='sdk for tiniyo api',
      author='Support',
      author_email='support@tiniyo.com',
      url='https://github.com/tiniyo/tiniyo-python.git',
      install_requires=['twilio==6.20.0'],
      long_description=long_description,
      long_description_content_type="text/markdown",
      packages=setuptools.find_packages(),
      include_package_data=True,
      classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent"
      ],
      python_requires='>=3.6'
)



from twilio.rest import Client as TwilioClient
from twilio.rest.api import Api as TwilioApi
from twilio.rest.api.v2010 import V2010 as TwilioV2010

def tiniyo_version(self,domain):
  super(V2010, self).__init__(domain)
  self.version = "v1"

class Client(TwilioClient):
    def __init__(self, username=None, password=None, account_sid=None, region=None,
                 http_client=None, environment=None):
        super().__init__(username,password, account_sid, region, http_client, environment)
        self._api = TwilioApi(self)
        self._api.base_url = 'https://api.tiniyo.com'
        self._api._v2010 = TwilioV2010(self._api)
        self._api._v2010.version = "v1"

